create or replace
PROCEDURE SP_ALTA_APLICACION (
   p_codigo		   	       IN  TFC_APLICACION.apl_codigo%TYPE,
   p_version        	   IN  TFC_APLICACION.apl_version%TYPE,
   p_fecha_alta     	   IN  TFC_APLICACION.apl_fecha_alta%TYPE,
   p_resolucion_minima 	 IN  TFC_APLICACION.apl_resolucion_minima%TYPE,
   p_activa			         IN TFC_APLICACION.apl_activa%TYPE,
   RSP              	   OUT VARCHAR2
)
IS
/*****************************************************************************
   Nombre  :  SP_ALTA_APLICACION
   Funcion :	Realizamos un alta en la tabla TFC_APLICACION
                   
   Parametros entrada:   p_version ,p_fecha_alta ,p_programa,p_resolucion_minima
                         p_activa,  RSO

   Parametos salida  :  RSP
						'OK' --> Ejecucion Correcta
            'ERROR: tipo de error" ejecucion no correcta
******************************************************************************/
/*** variables ****/
p_entrada  VARCHAR2(500);
iexiste INTEGER;
mensaje_error   VARCHAR2 (200);
campo_error 	VARCHAR2(20);
sProcedure VARCHAR2(20);

/*** Excepciones ****/

eNulo    EXCEPTION;
eFk     EXCEPTION;

BEGIN
  -- parametros de entrada 
   p_entrada:=    'p_codigo: '||p_codigo||
                  ',p_version: '||p_version||
                  ', p_fecha_alta: '||p_fecha_alta||
                  ', p_resolucion_minima: '||p_resolucion_minima||
                  ', p_activa: '||p_activa;
         

   sProcedure:='SP_ALTA_APLICACION';
   -- comprobacion de que los parametros de entrada tengan valores para poder 
   -- realizar el proceso
   IF (p_version IS NULL) THEN 
     campo_error:= 'version';
     RAISE eNulo;
   ELSIF (p_fecha_alta IS NULL) THEN 
     campo_error:= 'fecha_subida';
     RAISE eNulo;
	 
	 ELSIF  (p_resolucion_minima IS NULL) then 
			campo_error:='resolucion_minima';
			RAISE eNulo;
			ELSIF (p_activa IS NULL) then 
				campo_error:='activa';
				RAISE eNulo;
				ELSIF (p_codigo IS NULL) then 
				campo_error:='codigo';
				RAISE eNulo;
   END IF; 

  -- comprobamos que no exista la aplicacion
   SELECT COUNT (*)   INTO iexiste   FROM TFC_APLICACION
     WHERE APL_CODIGO = p_codigo and APL_VERSION=p_version;
     IF (iexiste> 0) THEN
        RAISE EFK;
    END IF;

   -- alta del la aplicacion
   
   INSERT INTO TFC_APLICACION (apl_codigo, apl_version, apl_fecha_alta, apl_resolucion_minima,apl_activa)
   VALUES (p_codigo,p_version,p_fecha_alta,p_resolucion_minima,p_activa);
   
   -- insertamos tabla de logs
   RSP:= 'OK:ALTA EFECTUADA ' || p_codigo || '/' ||p_version|| '';
   SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   COMMIT;
   -- gestion de excepciones controladas en las distintas operaciones realizadas 
EXCEPTION
   WHEN eNULO THEN
        RSP:= 'ERROR: el campo ' || campo_error || ' NO PUEDE SER NULO'; 
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
   WHEN EFk THEN
         RSP:= 'ERROR: ' || p_codigo || '/' ||p_version||' EL CODIGO DE APLICACION/VERSION YA EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
   WHEN OTHERS THEN
        ROLLBACK;
         
          mensaje_error := SUBSTR (SQLERRM, 1, 200);
          RSP:=    'ERROR: ' || mensaje_error;
          SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
              
END SP_ALTA_APLICACION;
/