create or replace
PROCEDURE SP_ALTA_DESARR_APL (
   p_codigo		   	         IN TFC_DESA_APLICACIONES.DEA_CODIGO%TYPE,
   p_version        	     IN TFC_DESA_APLICACIONES.DEA_VERSION%TYPE,
   p_desa       	         IN TFC_DESA_APLICACIONES.DEA_DESA%TYPE,
   RSP              	     OUT VARCHAR2
)

IS

/*****************************************************************************
   Nombre  :  SP_ALTA_DESARR_APL
   Funcion :	ealizamos un alta en la tabla de desarrolladores de aplicacones 
                   
   Parametros entrada:   p_codigo,p_version ,p_desa
   RSP              	   OUT VARCHAR2                
   Parametos salida  :  RSP
						'OK' --> Ejecucion Correcta
                 'ERROR: tipo de error" ejecucion no correcta
******************************************************************************/
/*** variables ****/
p_entrada  VARCHAR2(500);
iexiste INTEGER;
mensaje_error   VARCHAR2 (200);
campo_error 	VARCHAR2(20);
/*** Excepciones ****/
eNulo    EXCEPTION;
eFk     EXCEPTION;
eNoExiste EXCEPTION;
eNoExisteDESA EXCEPTION;
numero NUMBER;
sProcedure VARCHAR2(20);
BEGIN
	-- parametros de entrada
   p_entrada:=    'p_codigo: '||p_codigo||
                  ',p_version: '||p_version||
                  ', p_desa: '||p_desa;
                  
         
  sProcedure:= 'SP_ALTA_DESARR_APL';
  -- control  parametros de entrada 
   IF (p_version IS NULL) THEN 
     campo_error:= 'Version';
     RAISE eNulo;
   ELSIF (p_desa IS NULL) THEN 
     campo_error:= 'Desarrollador';
     RAISE eNulo;
	 
	 ELSIF  
       (p_codigo IS NULL) then 
				campo_error:='Codigo';
				RAISE eNulo;
   END IF; 

  -- comprobamos que exista esa aplicacion/version
   SELECT COUNT (*)   INTO iexiste   FROM TFC_APLICACION
    WHERE APL_CODIGO = p_codigo and APL_VERSION=p_version;
   IF (iexiste= 0) THEN
     RAISE eNoExiste;
   END IF;
   
   -- comprobamos que el desarrollador no este dado de alta para esa aplicacion/version
   SELECT COUNT (*)   INTO iexiste   FROM TFC_DESA_APLICACIONES
   WHERE DEA_CODIGO = p_codigo 
   AND DEA_VERSION = p_version
   AND DEA_DESA = p_desa;
   IF (iexiste> 0) THEN
     RAISE eFk;
   END IF;
   
   -- comprobamos que exista en el desarrollador 
   SELECT COUNT (*)   INTO iexiste   FROM TFC_DESARROLLADORES
    WHERE DES_CODIGO = p_desa;
   IF (iexiste= 0) THEN
     RAISE eNoExisteDESA;
   END IF;
   

   -- alta tabla desarrolladores 
   
   INSERT INTO TFC_DESA_APLICACIONES (DEA_CODIGO, DEA_VERSION, DEA_DESA)
   VALUES (p_codigo,p_version,p_desa);
   
-- ACTUALIZAMOS EL NUMERO DE APLICACIONES QUE TIENE EL DESARROLLADOR 

   SELECT COUNT (*)   INTO iexiste   FROM TFC_DESA_APLICACIONES
    WHERE DEA_DESA = p_desa ;
   IF (iexiste> 0) THEN
        SELECT des_aplicaciones_pub  INTO numero   FROM TFC_DESARROLLADORES
        WHERE DES_CODIGO = p_desa;
        update tfc_Desarrolladores set des_aplicaciones_pub=iexiste
          where des_codigo = p_desa;
   END IF;

 -- realizamos el alta en la tabla de logs
   RSP:= 'OK:ALTA DESARROLLADOR APLICACION  EFECTUADA ' || p_codigo || '/' ||p_version|| '/' ||p_desa|| '';
   SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   COMMIT;
 -- controlamos las excepciones
EXCEPTION
   WHEN eNULO THEN
        RSP:= 'ERROR: el campo ' || campo_error || ' NO PUEDE SER NULO'; 
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
   WHEN EFk THEN
         RSP:= 'ERROR: ' || p_codigo || '/' ||p_version||' EL Codigo/Version/Desarrollador   PARA ESTA APLICACION/VERSION YA EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   WHEN eNoExiste THEN
         RSP:= 'ERROR: ' || p_codigo || '/' ||p_version||' EL CODIGO DE APLICACION/VERSION NO EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);   
   WHEN eNoExisteDESA THEN
         RSP:= 'ERROR: ' || p_codigo || '/' ||p_desa||' EL CODIGO DE DESARROLLADOR NO EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);   
   WHEN OTHERS THEN
        ROLLBACK;
         
          mensaje_error := SUBSTR (SQLERRM, 1, 200);
          RSP:=    'ERROR: ' || mensaje_error;
          SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
          
              
END SP_ALTA_DESARR_APL;
/