create or replace
PROCEDURE SP_ALTA_DESARROLLADOR (
   p_codigo		   	             IN  TFC_DESARROLLADORES.des_codigo%TYPE,
   p_nombre_empresa            IN  TFC_DESARROLLADORES.des_nombre_empresa%TYPE,
   p_representante_legal       IN  TFC_DESARROLLADORES.des_representante_legal%TYPE,
   p_pais              	       IN  TFC_DESARROLLADORES.des_pais%TYPE,
   p_cif			                 IN TFC_DESARROLLADORES.des_cif%TYPE,
   p_direccion  		   	       IN  TFC_DESARROLLADORES.des_direccion%TYPE,
   p_cpostal                   IN  TFC_DESARROLLADORES.des_cpostal%TYPE,
   p_poblacion                 IN  tfc_desarrolladores.des_poblacion%TYPE,
   p_provincia              	 IN  TFC_DESARROLLADORES.des_provincia%TYPE,
   p_telefono                  IN tfc_desarrolladores.des_telefono%TYPE,
   p_fax                       IN tfc_desarrolladores.des_fax%TYPE,
   p_email                     IN tfc_desarrolladores.des_email%TYPE,
   p_aplicaciones_pub          IN tfc_desarrolladores.des_aplicaciones_pub%TYPE,
   RSP              	         OUT VARCHAR2
)

IS

/*****************************************************************************
   Nombre  :  SP_ALTA_DESARROLLADOR
   Funcion :	realizamos un alta en la tabla TFC_DESARROLLADORES
                   
   Parametros entrada:  p_codigo,p_nombre_empresa ,p_representante_legal ,p_programa,p_pais
                        p_cif,p_direccion,p_cpostal,p_poblacion,p_provincia,p_telefono,
                        p_fax,p_email,p_aplicaciones_pub
   RSP              	 OUT VARCHAR2                
   Parametos salida  :  RSP
						'OK'+ mensaje  --> Ejecucion Correcta
            'ERROR: tipo de error" ejecucion no correcta
******************************************************************************/
/*** variables ****/
p_entrada  VARCHAR2(500);
iexiste INTEGER;
mensaje_error   VARCHAR2 (200);
campo_error 	VARCHAR2(20);
sProcedure  VARCHAR2(20);
/*** Excepciones ****/
eNulo    EXCEPTION;
eFk     EXCEPTION;
ePaisNoExiste EXCEPTION;
BEGIN
-- parametros de entrada 
   p_entrada:=    '  p_codigo: '||p_codigo||
                  ', p_nombre_empresa: '||p_nombre_empresa||
                  ', p_representante_legal: '||p_representante_legal||
                  ', p_pais: '||p_pais||
                  ', p_cif: '||p_cif||
                  ', p_direccion: '||p_direccion||
                  ', p_cpostal: '||p_cpostal||
                  ', p_poblacion: '||p_poblacion||
                  ', p_provincia: '||p_provincia||
                  ', p_telefono: '||p_telefono||
                  ', p_fax: '||p_fax||
                  ', p_email: '||p_email||
                  ', p_aplicaciones_pub: '||p_aplicaciones_pub;
                                    
         

  sProcedure:= 'SP_ALTA_DESARROLLADO';
  -- controlamos los parametros de entrada para poder ser procesados
   IF (p_nombre_empresa IS NULL) THEN 
     campo_error:= 'nombre_empresa';
     RAISE eNulo;
   ELSIF (p_representante_legal IS NULL) THEN 
     campo_error:= 'Representante legal ';
     RAISE eNulo;
	 
	 ELSIF  (p_pais IS NULL) then 
			campo_error:='pais';
			RAISE eNulo;
			ELSIF (p_cif IS NULL) then 
				campo_error:='cif';
				RAISE eNulo;
				ELSIF (p_codigo IS NULL) then 
				campo_error:='codigo';
				RAISE eNulo;
   END IF; 

  -- comprobamos que no exista el desarrollador para dar de alta 
   SELECT COUNT (*)   INTO iexiste   FROM TFC_DESARROLLADORES
    WHERE des_CODIGO = p_codigo ;

   IF (iexiste> 0) THEN
     RAISE EFK;
   END IF;
   -- comprobamos que exista el pais 
   SELECT COUNT (*)   INTO iexiste   FROM TFC_PAISES
    WHERE PAI_CODIGO = p_pais  ;

   IF (iexiste= 0) THEN
     RAISE ePaisNoExiste;
   END IF;
   -- damos de alta la tabla de desarrolladores 
   
   INSERT INTO TFC_DESARROLLADORES (des_codigo, des_nombre_empresa, des_representante_legal, des_pais,des_cif,des_direccion,des_cpostal,des_poblacion,des_provincia,des_telefono,des_fax,des_email,des_aplicaciones_pub)
   VALUES (p_codigo,p_nombre_empresa,p_representante_legal,p_pais,p_cif,p_direccion,p_cpostal,p_poblacion,p_provincia,p_telefono,p_fax,p_email,p_aplicaciones_pub);
   

   -- damos de alta la tabla de logs
   RSP:= 'OK:ALTA EFECTUADA ' || p_codigo || '/' ||p_nombre_empresa|| '';
   SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   COMMIT;
   -- control de las excepciones
EXCEPTION
   WHEN eNULO THEN
        RSP:= 'ERROR: el campo ' || campo_error || ' NO PUEDE SER NULO'; 
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
   WHEN EFk THEN
         RSP:= 'ERROR: ' || p_codigo || '/' ||p_nombre_empresa||' EL CODIGO DE DESARROLLADOR  YA EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   WHEN ePaisNoExiste THEN
         RSP:= 'ERROR: ' || p_codigo|| '/' ||p_pais||' EL CODIGO DE  PAIS PARA ESTE DESARROLLADOR  NO  EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);   
   WHEN OTHERS THEN
        ROLLBACK;
         
          mensaje_error := SUBSTR (SQLERRM, 1, 200);
          RSP:=    'ERROR: ' || mensaje_error;
          SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
              
END SP_ALTA_DESARROLLADOR;
/