create or replace
PROCEDURE SP_ALTA_IDIOMAS_APL (
   p_codigo		   	         IN  TFC_IDIOMAS_APLICACIONES.aid_codigo%TYPE,
   p_version        	     IN  TFC_IDIOMAS_APLICACIONES.aid_version%TYPE,
   p_idioma     	         IN  TFC_IDIOMAS_APLICACIONES.aid_idioma%TYPE,
   p_descripcion   	       IN  TFC_IDIOMAS_APLICACIONES.aid_descripcion%TYPE,
   p_urlvideo			         IN TFC_IDIOMAS_APLICACIONES.aid_urlvideo%TYPE,
   RSP              	     OUT VARCHAR2
)

IS

/*****************************************************************************
   Nombre  :SP_ALTA_IDIOMAS_APL
   Funcion :Realizamos un alta en la tabla TFC_IDIOMAS_APLICACIONES
                   
   Parametros entrada:p_version ,p_fecha_alta ,p_idioma,p_descripcion,p_urlvideo
						 
   RSP              	 OUT VARCHAR2                
   Parametos salida  :  RSP
						'OK' --> Ejecucion Correcta
                 'ERROR: tipo de error" ejecucion no correcta
******************************************************************************/
/*** variables ****/
p_entrada  VARCHAR2(500);
iexiste INTEGER;
mensaje_error   VARCHAR2 (200);
campo_error 	VARCHAR2(20);
/*** Excepciones ****/
eNulo    EXCEPTION;
eFk     EXCEPTION;
eNoExiste EXCEPTION;
eNoExisteIdioma EXCEPTION;
sProcedure VARCHAR2(20);
BEGIN
-- parametros de entrada 
   p_entrada:=    'p_codigo: '||p_codigo||
                  ',p_version: '||p_version||
                  ', p_idioma: '||p_idioma||
                  ', p_descripcion: '||p_descripcion||
                   ', p_urlvideo: '||p_urlvideo;
         
  sProcedure:= 'SP_ALTA_IDIOMAS_APL';
  -- control parametros de entrada 
   IF (p_version IS NULL) THEN 
     campo_error:= 'version';
     RAISE eNulo;
   ELSIF (p_idioma IS NULL) THEN 
     campo_error:= 'Idioma';
     RAISE eNulo;
	 
	 ELSIF  (p_descripcion IS NULL) then 
			campo_error:='Descripcion';
			RAISE eNulo;
			ELSIF (p_urlvideo IS NULL) then 
				campo_error:='Url Video';
				RAISE eNulo;
				ELSIF (p_codigo IS NULL) then 
				campo_error:='codigo';
				RAISE eNulo;
   END IF; 

  -- comprobamos que exista la aplicacion
   SELECT COUNT (*)   INTO iexiste   FROM TFC_APLICACION
    WHERE APL_CODIGO = p_codigo and APL_VERSION=p_version;
   IF (iexiste= 0) THEN
     RAISE eNoExiste;
   END IF;
   -- comprobamos que exista el idioma a dar de alta 
   SELECT COUNT (*)   INTO iexiste   FROM TFC_IDIOMAS
    WHERE IDI_CODIGO = p_idioma;
   IF (iexiste= 0) THEN
     RAISE eNoExisteIdioma;
   END IF;
  -- comprobamos que NO EXISTE el idioma para la aplicacion seleccionada 
   SELECT COUNT (*)   INTO iexiste   FROM TFC_IDIOMAS_APLICACIONES
    WHERE AID_CODIGO = p_codigo and AID_VERSION=p_version and AID_IDIOMA=p_idioma;
   IF (iexiste> 0) THEN
     RAISE eFk;
   END IF;
   
   -- alta del idioma/aplicacion
   
   INSERT INTO TFC_IDIOMAS_APLICACIONES (aid_codigo, aid_version, aid_idioma, aid_descripcion,aid_urlvideo)
   VALUES (p_codigo,p_version,p_idioma,p_descripcion,p_urlvideo);
   
 -- alta tabla de logs 
   
   RSP:= 'OK:ALTA IDIOMA EFECTUADA' || p_codigo || '/' ||p_version|| '/' ||p_idioma|| '';
   SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   COMMIT;
   -- control de las excepciones 
EXCEPTION
   WHEN eNULO THEN
        RSP:= 'ERROR: el camp ' || campo_error || ' NO PUEDE SER NULO'; 
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
   WHEN EFk THEN
         RSP:= 'ERROR: ' || p_codigo || '/' ||p_version||' EL IDIOMA PARA ESTA APLICACION/VERSION YA EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   WHEN eNoExiste THEN
         RSP:= 'ERROR: ' || p_codigo || '/' ||p_version||' EL CODIGO DE APLICACION/VERSION NO EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);   
   WHEN eNoExisteIdioma THEN
         RSP:= 'ERROR: ' || p_codigo || '/' ||p_idioma||' EL CODIGO DE IDIOMA NO EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);   
   WHEN OTHERS THEN
        ROLLBACK;
         
          mensaje_error := SUBSTR (SQLERRM, 1, 200);
          RSP:=    'ERROR: ' || mensaje_error;
          SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
              
END SP_ALTA_IDIOMAS_APL;
/