create or replace
PROCEDURE SP_BAJA_APLICACION (
   p_codigo		   	       IN  TFC_APLICACION.apl_codigo%TYPE,
   p_version             IN  tfc_aplicacion.apl_version%TYPE,
   RSP              	   OUT VARCHAR2
)
IS
/*****************************************************************************
   Nombre  : SP_BAJA_APLICACION
   Funcion :  Realizamos la baja de la tabla TFC_APLICACION,TFC_IDIOMAS_APLICACIONES,
              TFC_PAISES_APLICACONES,TFC_SISTEMAS_APLICACIONES,TFC_DESA_APLICACIONES
                   
   Parametros entrada:   p_codigo,p_version
            
   RSP              	         
   Parametos salida  :  RSP
						'OK' --> Ejecucion Correcta
                        'ERROR: tipo de error" ejecucion no correcta
******************************************************************************/
/*** variables ****/
p_entrada  VARCHAR2(500);
iexiste INTEGER;
mensaje_error   VARCHAR2 (200);
campo_error 	VARCHAR2(20);
sProcedure VARCHAR2(20);
/*** Excepciones ****/
eNulo    EXCEPTION;
eNoExiste     EXCEPTION;
eTieneDescargas EXCEPTION;
BEGIN
	-- parametros de entrada 
   p_entrada:=    ' p_codigo: '||p_codigo||
                  ',p_version: '||p_version;
                  
  sProcedure:='SP_BAJA_APLICACION';
  -- control parametros de entrada 
   IF (p_codigo IS NULL) THEN 
     campo_error:= 'codigo';
     RAISE eNulo;
   ELSIF (p_version IS NULL) THEN 
          campo_error:= 'version';
          RAISE eNulo;
   END IF ;
	 

  -- comprobamos que Exista la aplicacion
   SELECT COUNT (*)   INTO iexiste   FROM TFC_APLICACION
   WHERE APL_CODIGO = p_codigo 
   AND APL_VERSION = p_version;
   IF (iexiste= 0) THEN
     RAISE eNoExiste;
   END IF;

   -- comprobamos que no existan descargas de la aplicacion que se quiere eliminar
 
   SELECT COUNT (*)   INTO iexiste   FROM TFC_DESCARGAS_APLICACIONES
    WHERE DES_CODIGO = p_codigo 
    AND DES_VERSION = p_version;
    IF (iexiste> 0) THEN
       RAISE eTieneDescargas;
    END IF;
    
   -- BORRAMOS LOS DESARROLLADORES DE LA APLICACION
   DELETE FROM TFC_DESA_APLICACIONES
   WHERE dea_codigo = p_codigo and dea_version = p_version;
  
   RSP:= 'OK:BAJA DESARROLLADORE/APLICACION EFECTUADA  ' || p_codigo || '/' ||p_version|| '';
   SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP); 
   
   -- BORRAMOS LOS IDIOMAS  DE LA APLICACION
   DELETE FROM tfc_idiomas_aplicaciones
   WHERE aid_codigo = p_codigo and aid_version = p_version;
  
   RSP:= 'OK:BAJA IDIOMAS/APLICACION EFECTUADA  ' || p_codigo || '/' ||p_version|| '';
   SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   
   
   -- BORRAMOS LOS PAISES DONDE TENEMOS DEFINIDAS LAS APLICACIONES
   DELETE FROM tfc_paises_aplicaciones
   WHERE app_codigo = p_codigo and app_version = p_version;
  
   RSP:= 'OK:BAJA PAIS/APLICACION EFECTUADA  ' || p_codigo || '/' ||p_version|| '';
   SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP); 
   
   -- BORRAMOS LOS SISTEMAS OPERATIVOS DE LAS APLICACIONES
   DELETE FROM tfc_sistema_aplicaciones 
   WHERE SOP_codigo = p_codigo and SOP_version = p_version;
  
   RSP:= 'OK:BAJA SISTEMAS / APLICACION EFECTUADA  ' || p_codigo || '/' ||p_version|| '';
   SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   
   
   -- borramos la aplicacion 
   
   DELETE FROM  TFC_APLICACION WHERE apl_codigo = p_codigo and apl_version = p_version;
  -- alta tabla de logs 
   RSP:= 'OK:BAJA EFECTUADA ' || p_codigo || '/' ||p_version|| '';
   SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   COMMIT;
   -- control de excepciones 
EXCEPTION
   WHEN eNULO THEN
        RSP:= 'ERROR: el campo ' || campo_error || ' NO PUEDE SER NULO'; 
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   WHEN eTieneDescargas THEN
        RSP:= 'ERROR: LA APLICACION QUE SE QUIERE BORRAR TIENE DESCARGAS. NO SE PUEDE BORRAR!!!';        
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);    
   WHEN eNoExiste THEN
        RSP:= 'ERROR: EL CODIGO DE APLICACION NO EXISTE';        
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
   WHEN OTHERS THEN
        ROLLBACK;
         
          mensaje_error := SUBSTR (SQLERRM, 1, 200);
          RSP:=    'ERROR: ' || mensaje_error;
          SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
              
END SP_BAJA_APLICACION;
/