create or replace
PROCEDURE SP_BAJA_DESARR_APL (
   p_codigo		   	         IN TFC_DESA_APLICACIONES.DEA_CODIGO%TYPE,
   p_version        	     IN TFC_DESA_APLICACIONES.DEA_VERSION%TYPE,
   p_desa       	         IN TFC_DESA_APLICACIONES.DEA_DESA%TYPE,
   RSP              	     OUT VARCHAR2
)

IS

/*****************************************************************************
   Nombre  : SP_BAJA_DESARR_APLICACIONES
   Funcion : Realizamos la baja de un desarrollador de una aplicacion
                   
   Parametros entrada:   p_codigo,p_version ,p_desa
   RSP              	 OUT VARCHAR2                
   Parametos salida  :  RSP
						'OK' --> Ejecucion Correcta
                 'ERROR: tipo de error" ejecucion no correcta
******************************************************************************/
/*** variables ****/
p_entrada  VARCHAR2(500);
iexiste INTEGER;
mensaje_error   VARCHAR2 (200);
campo_error 	VARCHAR2(20);
/*** Excepciones ****/
eNulo    EXCEPTION;
eFk     EXCEPTION;
eNoExiste EXCEPTION;
eNoExisteDESA EXCEPTION;
eTieneDescargas EXCEPTION;
NUMERO NUMBER;
sProcedure VARCHAR2(20);
BEGIN
-- parametros de entrada 
   p_entrada:=    'p_codigo: '||p_codigo||
                  ',p_version: '||p_version||
                  ', p_desa: '||p_desa;
                  
         
  sProcedure:= 'SP_BAJA_DESARR_APL';
  -- control parametros de entrada 
   IF (p_version IS NULL) THEN 
     campo_error:= 'version';
     RAISE eNulo;
   ELSIF (p_desa IS NULL) THEN 
     campo_error:= 'DESA';
     RAISE eNulo;
	 
	 ELSIF  
       (p_codigo IS NULL) then 
				campo_error:='codigo';
				RAISE eNulo;
   END IF; 

    -- comprobamos que el desarrollador no tenga aplicaciones 
   SELECT COUNT (*)   INTO iexiste   FROM TFC_DESA_APLICACIONES
   WHERE DEA_CODIGO = p_codigo 
   AND DEA_VERSION = p_version
   AND DEA_DESA = p_desa;
   IF (iexiste= 0) THEN
     RAISE eFk;
   END IF;
  -- comprobamos que no existan descargas de la aplicacion que se quiere eliminar el desarrollador
 
   SELECT COUNT (*)   INTO iexiste   FROM TFC_DESCARGAS_APLICACIONES
    WHERE DES_CODIGO = p_codigo 
    AND DES_VERSION = p_version;
    IF (iexiste> 0) THEN
       RAISE eTieneDescargas;
    END IF;
        

  -- borramos el desarrollador de una aplicacion 
  DELETE FROM  TFC_DESA_APLICACIONES
  WHERE DEA_CODIGO = p_codigo
  AND DEA_VERSION = p_version
  AND DEA_DESA = p_desa;
  
  -- actualizamos las aplicaciones del desarrollador 
    SELECT COUNT (*)   INTO iexiste   FROM TFC_DESA_APLICACIONES
    WHERE DEA_DESA = p_desa ;
   IF (iexiste> 0) THEN
        SELECT des_aplicaciones_pub  INTO numero   FROM TFC_DESARROLLADORES
        WHERE DES_CODIGO = p_desa;
        update tfc_Desarrolladores set des_aplicaciones_pub=iexiste
          where des_codigo = p_desa;
   END IF;

  -- damos de alta la tabla de logs
   RSP:= 'OK:BAJA DESARROLLADOR aplicacion  EFECTUADA' || p_codigo || '/' ||p_version|| '/' ||p_desa|| '';
   SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   COMMIT;
   -- controlamos las excepciones 
EXCEPTION
   WHEN eNULO THEN
        RSP:= 'ERROR: el camp ' || campo_error || ' NO PUEDE SER NULO'; 
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
   WHEN EFk THEN
         RSP:= 'ERROR: ' || p_codigo || '/' ||p_version||' EL Codigo/Version/Desarrollador PARA ESTA APLICACION/VERSION NO EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   WHEN eTieneDescargas THEN
         RSP:= 'ERROR: ' || p_codigo || '/' ||p_version||' EL Codigo/Version/Desarrollador PARA ESTA APLICACION TIENE DECARGAS.NO SE PERMITE LA BAJA';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   WHEN OTHERS THEN
        ROLLBACK;
         
          mensaje_error := SUBSTR (SQLERRM, 1, 200);
          RSP:=    'ERROR: ' || mensaje_error;
          SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
              
END SP_BAJA_DESARR_APL;
/