create or replace
PROCEDURE SP_BAJA_DESARROLLADOR (
   p_codigo		   	             IN  TFC_DESARROLLADORES.des_codigo%TYPE,
   RSP              	        OUT VARCHAR2
)

IS

/*****************************************************************************
   Nombre  :  SP_BAJA_DESARROLLADOR
   Funcion :	Realizamos la baja de la tabla TFC_DESARROLLADORES
                   
   Parametros entrada:   p_codigo
          
   RSP              	 OUT VARCHAR2                
   Parametos salida  :  RSP
						'OK' --> Ejecucion Correcta
                        'ERROR: tipo de error" ejecucion no correcta
******************************************************************************/
/*** variables ****/
p_entrada  VARCHAR2(500);
iexiste INTEGER;
mensaje_error   VARCHAR2 (200);
campo_error 	VARCHAR2(20);
sProcedure VARCHAR2(20);
/*** Excepciones ****/
eNulo    EXCEPTION;
eFk     EXCEPTION;
eTieneAplicaciones EXCEPTION;
BEGIN
-- parametros de entrada 
   p_entrada:=    'p_codigo: '||p_codigo;
                  
   sProcedure:='SP_BAJA_DESARRLLADO';
   
   IF (p_codigo IS NULL) then 
				campo_error:='codigo';
				RAISE eNulo;
   END IF; 

  -- comprobamos que exista el desarrollador 
   SELECT COUNT (*)   INTO iexiste   FROM TFC_DESARROLLADORES
    WHERE des_CODIGO = p_codigo ;
   IF (iexiste= 0) THEN
     RAISE EFK;
   END IF;
   
 -- comprobamos que no tenga aplicaciones desarrolladas 
   SELECT COUNT (*)   INTO iexiste   FROM TFC_DESA_APLICACIONES
    WHERE DEA_DESA = p_codigo ;
    IF (iexiste> 0) THEN
       RAISE eTieneAplicaciones;
    END IF;
   
   -- borramos el desarrollador 
   
   DELETE FROM TFC_DESARROLLADORES
    WHERE DES_CODIGO = p_codigo;
  
   -- damos de alta la tabla de logs 
   RSP:= 'OK:BAJA EFECTUADA ' || p_codigo ||  '';
   SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   COMMIT;
   -- controlamos las excepciones 
EXCEPTION
   WHEN eNULO THEN
        RSP:= 'ERROR: el campo ' || campo_error || ' NO PUEDE SER NULO'; 
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
   WHEN EFk THEN
         RSP:= 'ERROR: ' || p_codigo ||  ' EL CODIGO DE DESARROLLADOR NO EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   WHEN eTieneAplicaciones THEN
         RSP:= 'ERROR: ' || p_codigo|| ' ESTE DESARROLLADOR TIENE APLICACIONES DESARROLLADAS.NO SE PUEDE BORRAR';           
        SP_ALTA_LOGS(sProcedure , p_entrada, 'RSP: '||RSP);   
   WHEN OTHERS THEN
        ROLLBACK;
         
          mensaje_error := SUBSTR (SQLERRM, 1, 200);
          RSP:=    'ERROR: ' || mensaje_error;
          SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
              
END SP_BAJA_DESARROLLADOR;
/