create or replace
PROCEDURE SP_BAJA_DISP_USU (
   p_imei         IN  TFC_DISPOSITIVOS_USUARIO.DIU_IMEI%TYPE,
   RSP             OUT VARCHAR2
)
IS
/*****************************************************************************
   Nombre  : SP_BAJA_DISP_USU
   Funcion : Realizamos un alta en la tabla TFC_DISPOSITIVOS_USUARIO
                   
   Parametros entrada:  p_imei
   RSP              	 OUT VARCHAR2                
   Parametos salida  :  RSP
   			'OK' --> Ejecucion Correcta
        'ERROR: tipo de error" ejecucion no correcta
******************************************************************************/
/*** variables ****/
p_entrada  VARCHAR2(500);
iexiste INTEGER;
mensaje_error   VARCHAR2 (200);
campo_error 	VARCHAR2(20);
/*** Excepciones ****/
eNulo    EXCEPTION;
eFk     EXCEPTION;
eTieneDescargas EXCEPTION;
sProcedure VARCHAR2(20);
BEGIN
	-- parametros de entrada 
  p_entrada:=    'p_imei: '||p_imei;
         
  sProcedure:= 'SP_BAJA_DISP_USU';
  -- control parametros de entrada 
   IF (p_imei IS NULL) THEN 
     campo_error:= 'imei';
     RAISE eNulo;
        
   END IF; 
  -- comprobamos que EXISTE el imei en dispositivos de usuario
   SELECT COUNT (*)   INTO iexiste   FROM TFC_DISPOSITIVOS_USUARIO
    WHERE DIU_IMEI = p_imei;
    
   IF (iexiste=0) THEN
     RAISE eFk;
   END IF;
   
  --comprobacion de que el usuario no tenga descargas para ese imei
           
      SELECT COUNT (*)   INTO iexiste   FROM TFC_DESCARGAS_APLICACIONES 
        WHERE DES_IMEI = p_imei;
        IF (iexiste> 0) THEN
          RAISE eTieneDescargas;
         END IF;
       
   -- borramos el dispositivo de usuario 
 
  DELETE FROM TFC_DISPOSITIVOS_USUARIO 
    WHERE DIU_IMEI = p_imei;
    
  -- damos de alta la tabla de log
   RSP:= 'OK:BAJA DISPOSITIVO USUARIO IMEI ' || p_imei ||  '';
   SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   COMMIT;
  -- controlamos las excepciones  
EXCEPTION
   WHEN eNULO THEN
        RSP:= 'ERROR: el campo ' || campo_error || ' NO PUEDE SER NULO'; 
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
   WHEN EFk THEN
         RSP:= 'ERROR: ' || p_imei || ' EL DISPOSITIVO USUARIO  NO EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   WHEN eTieneDescargas THEN
         RSP:= 'ERROR: ' || p_imei || ' EL USUARIO HA REALIZADO DESCARGAS CON ESTE IMEI';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
    
   WHEN OTHERS THEN
        ROLLBACK;
         
          mensaje_error := SUBSTR (SQLERRM, 1, 200);
          RSP:=    'ERROR: ' || mensaje_error;
          SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
              
END SP_BAJA_DISP_USU;
/