create or replace
PROCEDURE SP_BAJA_IDIOMAS_APL (
   p_codigo		   	         IN  TFC_IDIOMAS_APLICACIONES.aid_codigo%TYPE,
   p_version        	     IN  TFC_IDIOMAS_APLICACIONES.aid_version%TYPE,
   p_idioma     	         IN  TFC_IDIOMAS_APLICACIONES.aid_idioma%TYPE,
   
   
   RSP              	     OUT VARCHAR2
)

IS

/*****************************************************************************
   Nombre  :                SP_BAJA_IDIOMAS_APL
   Funcion :				Realizamos la BAJA de la tabla TFC_IDIOMAS_APLICACIONES
                   
   Parametros entrada:  p_codigo, p_version ,p_idioma
						 
   RSP              	 OUT VARCHAR2                
   Parametos salida  :  RSP
   'OK' --> Ejecucion Correcta
                 'ERROR: tipo de error" ejecucion no correcta
******************************************************************************/
/*** variables ****/
p_entrada  VARCHAR2(500);
iexiste INTEGER;
mensaje_error   VARCHAR2 (200);
campo_error 	VARCHAR2(20);
/*** Excepciones ****/
eNulo    EXCEPTION;
eFk     EXCEPTION;
eNoExiste EXCEPTION;
eNoExisteIdioma EXCEPTION;
sProcedure VARCHAR2(20);
BEGIN
-- parametros de entrada 
   p_entrada:=    'p_codigo: '||p_codigo||
                  ',p_version: '||p_version||
                  ', p_idioma: '||p_idioma;
                  
                  
  sProcedure:= 'SP_BAJA_IDIOMAS_APL';
  -- control parametros de entrada 
   IF (p_version IS NULL) THEN 
     campo_error:= 'version';
     RAISE eNulo;
   ELSIF (p_idioma IS NULL) THEN 
     campo_error:= 'Idioma';
     RAISE eNulo;
	 
	 	ELSIF (p_codigo IS NULL) then 
				campo_error:='codigo';
				RAISE eNulo;
   END IF; 
  
   
   
  -- comprobamos que EXISTA el idioma para la aplicacion 
   SELECT COUNT (*)   INTO iexiste   FROM TFC_IDIOMAS_APLICACIONES
    WHERE AID_CODIGO = p_codigo and AID_VERSION=p_version and AID_IDIOMA=p_idioma;
    IF (iexiste= 0) THEN
       RAISE eNoExiste;
    END IF;
   -- borramos la tabla de idiomas aplicaciones
    DELETE FROM TFC_IDIOMAS_APLICACIONES 
        WHERE AID_CODIGO = p_codigo 
        AND AID_VERSION = p_version
        AND AID_IDIOMA = p_idioma;
   -- damos de alta la tabla de logs 
   RSP:= 'OK:BAJA IDIOMA EFECTUADA ' || p_codigo || '/' ||p_version|| '/' ||p_idioma|| '';
   SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   COMMIT;
   -- controlamos las excepciones 
EXCEPTION
   WHEN eNULO THEN
        RSP:= 'ERROR: el campo ' || campo_error || ' NO PUEDE SER NULO'; 
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
    
   WHEN eNoExiste THEN
         RSP:= 'ERROR: ' || p_codigo || '/' ||p_version||' EL CODIGO DE APLICACION/VERSION/IDIOMA NO EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);   
   
   WHEN OTHERS THEN
        ROLLBACK;
          mensaje_error := SUBSTR (SQLERRM, 1, 200);
          RSP:=    'ERROR: ' || mensaje_error;
          SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
              
END SP_BAJA_IDIOMAS_APL;
/