create or replace
PROCEDURE SP_BAJA_PAISES_APL (
   p_codigo		   	       IN  TFC_PAISES_APLICACIONES.app_codigo%TYPE,
   p_version             IN  TFC_PAISES_APLICACIONES.app_version%TYPE,
   p_pais                IN  TFC_PAISES_APLICACIONES.APP_PAIS%TYPE,
   p_divisa              IN  TFC_PAISES_APLICACIONES.APP_DIVISA%TYPE,
   
   RSP              	   OUT VARCHAR2
)

IS

/*****************************************************************************
   Nombre  :   SP_BAJA_PAISES_APL
   Funcion :	 Realizamos la baja de la tabla TFC_PAISES_APLICACIONES
                   
   Parametros entrada:   p_codigo,p_version,p_pais,p_divisa
            
   RSP              	         
   Parametos salida  :  RSP
						'OK' --> Ejecucion Correcta
                        'ERROR: tipo de error" ejecucion no correcta
******************************************************************************/
/*** variables ****/
p_entrada  VARCHAR2(500);
iexiste INTEGER;
mensaje_error   VARCHAR2 (200);
campo_error 	VARCHAR2(20);
/*** Excepciones ****/
eNulo    EXCEPTION;
eNoExiste     EXCEPTION;
sProcedure VARCHAR2(50);
BEGIN
	-- parametros de entrada 
   p_entrada:=    ' p_codigo: '||p_codigo||
                  ',p_version: '||p_version||
                   ' p_pais: '||p_pais||
                    ' p_divisa: '||p_divisa;
                  
  sProcedure:= 'sp_baja_paises_apl';
  -- controlamos los parametros de entrada 
   IF (p_codigo IS NULL) THEN 
     campo_error:= 'codigo';
     RAISE eNulo;
   ELSIF (p_version IS NULL) THEN 
          campo_error:= 'version';
          RAISE eNulo;
    ELSIF (p_pais IS NULL) THEN 
     campo_error:= 'pais';
     RAISE eNulo;
   ELSIF (p_divisa IS NULL) THEN 
          campo_error:= 'divisa';
          RAISE eNulo;
   END IF ;
	 

  -- comprobamos que  exista la fila quie vamos a borrar 
   SELECT COUNT (*)   INTO iexiste   FROM TFC_PAISES_APLICACIONES
   WHERE APP_CODIGO = p_codigo 
   AND APP_VERSION = p_version
   AND APP_DIVISA = p_divisa
   AND APP_PAIS = p_pais;

   IF (iexiste= 0) THEN
     RAISE eNoExiste;
   END IF;

   -- borramos la tabla de paises   
   DELETE FROM  TFC_PAISES_APLICACIONES WHERE app_codigo = p_codigo and app_version = p_version and app_pais=p_pais and app_divisa = p_divisa;
   -- damos de alta la tabla de logs 
   RSP:= 'OK:BAJA PAIS/DIVISA EFECTUADA' || p_codigo || '/' ||p_version|| '/' ||p_pais|| '/' ||p_divisa|| '';
   SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   COMMIT;
   -- controlamos las excepciones 
EXCEPTION
   WHEN eNULO THEN
        RSP:= 'ERROR: el campO ' || campo_error || ' NO PUEDE SER NULO'; 
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
   WHEN eNoExiste THEN
        RSP:= 'ERROR: EL CODIGO DE APLICACION NO EXISTE';        
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
   WHEN OTHERS THEN
        ROLLBACK;
         
          mensaje_error := SUBSTR (SQLERRM, 1, 200);
          RSP:=    'ERROR: ' || mensaje_error;
          SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
              
END SP_BAJA_PAISES_APL;
/