create or replace
PROCEDURE SP_BAJA_SISTEMA_APL (
   p_codigo		   	         IN  TFC_SISTEMA_APLICACIONES.SOP_CODIGO%TYPE,
   p_version        	     IN  TFC_SISTEMA_APLICACIONES.SOP_VERSION%TYPE,
   p_soperativo            IN  TFC_SISTEMA_APLICACIONES.SOP_soperativo%TYPE,
  
   RSP              	     OUT VARCHAR2
)

IS

/*****************************************************************************
   Nombre  :                SP_BAJA_SISTEMA_APLICACIONES
   Funcion :				Realizamos la baja en la tabla TFC_SISTEMA_APLICACIONES
                   
   Parametros entrada:   p_codigo,p_version ,p_soperativo,p_enlacef,p_medida
						 
   RSP              	 OUT VARCHAR2                
   Parametos salida  :  RSP
						'OK' --> Ejecucion Correcta
                 'ERROR: tipo de error" ejecucion no correcta
******************************************************************************/
/*** variables ****/
p_entrada  VARCHAR2(500);
iexiste INTEGER;
mensaje_error   VARCHAR2 (200);
campo_error 	VARCHAR2(20);
/*** Excepciones ****/
eNulo    EXCEPTION;
eFk     EXCEPTION;
eNoExiste EXCEPTION;
eNoExistesoperativo EXCEPTION;

sProcedure VARCHAR2(20);
BEGIN
  -- parametros de entrada 
   p_entrada:=    'p_codigo: '||p_codigo||
                  ',p_version: '||p_version||
                  ', p_soperativo: '||p_soperativo;
                   

         
  sProcedure:= 'SP_BAJA_SISTEMA_APL';
  -- controlamos los parametros de entrada 
   IF (p_version IS NULL) THEN 
     campo_error:= 'version';
     RAISE eNulo;
   ELSIF (p_soperativo IS NULL) THEN 
     campo_error:= 'soperativo';
     RAISE eNulo;
	 
	 ELSIF   (p_codigo IS NULL) then 
				campo_error:='codigo';
				RAISE eNulo;
   END IF; 

   -- comprobamos si existen aplicaciones de ese sistema operativo 
   SELECT COUNT (*)   INTO iexiste   FROM TFC_SISTEMA_APLICACIONES
   WHERE SOP_CODIGO = p_codigo 
   AND SOP_VERSION = p_version
   AND SOP_SOPERATIVO = p_soperativo;
   IF (iexiste= 0) THEN
     RAISE eFk;
   END IF;
    -- borramos la fila de aplicacones sistema operativo 
   
   DELETE FROM TFC_SISTEMA_APLICACIONES 
   WHERE SOP_CODIGO = p_codigo 
   AND SOP_VERSION = p_version
   AND SOP_SOPERATIVO = p_soperativo;
-- alta tabla de logs 
   RSP:= 'OK';
   RSP:= 'OK:BAJA Soperativo Aplicacion  EFECTUADA ' || p_codigo || '/' ||p_version|| '/' ||p_soperativo|| '';
   SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   COMMIT;
   -- control de excepciones 
EXCEPTION
   WHEN eNULO THEN
        RSP:= 'ERROR: el camp ' || campo_error || ' NO PUEDE SER NULO'; 
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
             
   WHEN EFk THEN
         RSP:= 'ERROR: ' || p_codigo || '/' ||p_version||' EL Codigo/Version/Sistema Operativo  PARA ESTA APLICACION/VERSION NO EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   WHEN eNoExiste THEN
         RSP:= 'ERROR: ' || p_codigo || '/' ||p_version||' EL CODIGO DE APLICACION/VERSION NO EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);   
   WHEN OTHERS THEN
        ROLLBACK;
          mensaje_error := SUBSTR (SQLERRM, 1, 200);
          RSP:=    'ERROR: ' || mensaje_error;
          SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
              
END SP_BAJA_SISTEMA_APL;
/