create or replace
PROCEDURE SP_BAJA_USUARIO (
   p_movilusuario	         IN  TFC_USUARIOS.USU_MOVILUSUARIO%TYPE,
   RSP              	     OUT VARCHAR2
)

IS

/*****************************************************************************
   Nombre  : SP_BAJA_USUARIO
   Funcion : Realizamos una baja de la tabla de usuarios TFC_USUARIOS
                   
   Parametros entrada:  p_movilusuario
   RSP              	 OUT VARCHAR2                
   Parametos salida  :  RSP
						'OK' + mensaje  --> Ejecucion Correcta
            'ERROR: tipo de error" ejecucion no correcta
******************************************************************************/
/*** variables ****/
p_entrada  VARCHAR2(500);
iexiste INTEGER;
mensaje_error   VARCHAR2 (200);
campo_error 	VARCHAR2(20);

/*** Excepciones ****/
eNulo    EXCEPTION;
eFk     EXCEPTION;
eNoExiste EXCEPTION;
eNoExistePais EXCEPTION;
eNoExisteOperador EXCEPTION;
eTieneDescargas EXCEPTION;
sProcedure VARCHAR2(20);
BEGIN
-- parametros de entrada 
   p_entrada:=    'p_movilusuario: '||p_movilusuario;
                  
         
  sProcedure:= 'SP_BAJA_USUARIO';
  -- control parametros de entrada 
   IF (p_movilusuario IS NULL) then 
				campo_error:='movilusuario';
				RAISE eNulo;
   END IF; 
  -- comprobamos que el usuario que vamos a borrar no tenga descargas realizadas 
  
  DECLARE 
     p_imei       	        TFC_DISPOSITIVOS_USUARIO.DIU_IMEI%TYPE;
    cursor c1 IS 
      SELECT  DIU_IMEI  FROM TFC_DISPOSITIVOS_USUARIO
        WHERE DIU_MOVILUSUARIO = p_movilusuario;
    BEGIN
      OPEN c1;
      LOOP 
        FETCH c1 INTO p_imei;
        SELECT COUNT (*)   INTO iexiste   FROM TFC_DESCARGAS_APLICACIONES 
          WHERE DES_IMEI = p_imei;
          IF (iexiste> 0) THEN
            RAISE eTieneDescargas;
           END IF;
        EXIT WHEN c1%NOTFOUND;
      END LOOP;
      CLOSE c1;
    
    END;
  
  
  
  -- comprobamos que EXISTE el usuario que vamos a borrar 
   SELECT COUNT (*)   INTO iexiste   FROM TFC_USUARIOS
    WHERE USU_MOVILUSUARIO = p_movilusuario;
    IF (iexiste= 0) THEN
      RAISE eFk;
     END IF;
   
   -- Realizamos la Baja de los dispositivos 
   DELETE FROM  TFC_DISPOSITIVOS_USUARIO
   WHERE DIU_MOVILUSUARIO = p_movilusuario;
   -- alta log 
   RSP:= 'OK';
   RSP:= 'OK:BAJA USUARIO DISPOSITIVOS ' || p_MOVILUSUARIO ||  '';
   SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   
   -- borramos el usuario 
   DELETE FROM  TFC_USUARIOS 
   WHERE USU_MOVILUSUARIO = p_movilusuario;
   
  -- alta log
   
   RSP:= 'OK';
   RSP:= 'OK:BAJA USUARIO ' || p_MOVILUSUARIO ||  '';
   SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   COMMIT;
   -- control de excepciones 
EXCEPTION
   WHEN eNULO THEN
        RSP:= 'ERROR: el campo ' || campo_error || ' NO PUEDE SER NULO'; 
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
   WHEN EFk THEN
         RSP:= 'ERROR: ' || p_movilusuario || ' EL USUARIO  NO EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   WHEN eTieneDescargas THEN
         RSP:= 'ERROR: ' || p_movilusuario || ' EL USUARIO TIENE DESCARGAS REALIZADAS NO SE PERMITE BORRAR ';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   WHEN OTHERS THEN
        ROLLBACK;
         
          mensaje_error := SUBSTR (SQLERRM, 1, 200);
          RSP:=    'ERROR: ' || mensaje_error;
          SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
              
END SP_BAJA_USUARIO;
/