create or replace
PROCEDURE SP_MODIF_APLICACION (
   p_codigo		   	       IN  TFC_APLICACION.apl_codigo%TYPE,
   p_version        	   IN  TFC_APLICACION.apl_version%TYPE,
   p_fecha_alta     	   IN  TFC_APLICACION.apl_fecha_alta%TYPE,
   p_resolucion_minima 	 IN  TFC_APLICACION.apl_resolucion_minima%TYPE,
   p_activa			         IN  TFC_APLICACION.apl_activa%TYPE,
   p_fecha_fin_soporte   IN  TFC_APLICACION.apl_fecha_fin_soporte%TYPE,
   RSP              	   OUT VARCHAR2
)

IS

/*****************************************************************************
   Nombre  :  SP_MODIF_APLICACION
   Funcion :	realizamos la modificacion en la tabla TFC_APLICACION
                   
   Parametros entrada:   p_version ,p_fecha_alta ,p_programa,p_resolucion_minima
                         p_activa
   RSP              	 OUT VARCHAR2                
   Parametos salida  :  RSP
						'OK' --> Ejecucion Correcta + explicacion
             'ERROR: tipo de error" ejecucion no correcta
******************************************************************************/
/*** variables ****/
p_entrada  VARCHAR2(500);
iexiste INTEGER;
mensaje_error   VARCHAR2 (200);
campo_error 	VARCHAR2(20);
sProcedure VARCHAR2(50);
/*** Excepciones ****/
eNulo    EXCEPTION;
eFk     EXCEPTION;
eNoExiste EXCEPTION;
BEGIN
   -- parametros de entrada 
   p_entrada:=    'p_codigo: '||p_codigo||
                  ',p_version: '||p_version||
                  ', p_fecha_alta: '||p_fecha_alta||
                  ', p_resolucion_minima: '||p_resolucion_minima||
                   ', p_activa: '||p_activa||
                   ',p_fecha_fin_soporte: '||p_fecha_fin_soporte;
         
   sProcedure:='sp_modif_aplicacion';
  -- control parametros de entrada 
   IF (p_version IS NULL) THEN 
     campo_error:= 'version';
     RAISE eNulo;
   ELSIF (p_fecha_alta IS NULL) THEN 
     campo_error:= 'fecha_subida';
     RAISE eNulo;
	 
	 ELSIF  (p_resolucion_minima IS NULL) then 
			campo_error:='resolucion_minima';
			RAISE eNulo;
			ELSIF (p_activa IS NULL) then 
				campo_error:='activa';
				RAISE eNulo;
				ELSIF (p_codigo IS NULL) then 
				campo_error:='codigo';
				RAISE eNulo;
   END IF; 

  -- comprobamos que   exista la aplicacion
   SELECT COUNT (*)   INTO iexiste   FROM TFC_APLICACION
    WHERE APL_CODIGO = p_codigo and APL_VERSION=p_version;

   IF (iexiste= 0) THEN
     RAISE eNoExiste;
   END IF;

   -- modificacion del la aplicacion
   UPDATE TFC_APLICACION  SET APL_FECHA_ALTA=p_fecha_alta,
    APL_RESOLUCION_MINIMA=p_resolucion_minima,
    APL_ACTIVA = p_activa,
    APL_FECHA_FIN_SOPORTE = p_fecha_fin_soporte
    WHERE APL_CODIGO = p_codigo 
    AND APL_VERSION = p_version;
   
  -- alta logs 
   RSP:= 'OK:MODIF EFECTUADA ' || p_codigo || '/' ||p_version|| '';
   SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   COMMIT;
   --control excepciones 
EXCEPTION
   WHEN eNULO THEN
        RSP:= 'ERROR: el campo ' || campo_error || ' NO PUEDE SER NULO'; 
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
   WHEN eNoExiste THEN
         RSP:= 'ERROR: ' || p_codigo || '/' ||p_version||' EL CODIGO DE APLICACION/VERSION NO EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
   WHEN OTHERS THEN
        ROLLBACK;
         
          mensaje_error := SUBSTR (SQLERRM, 1, 200);
          RSP:=    'ERROR: ' || mensaje_error;
          SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
              
END SP_MODIF_APLICACION;
/