create or replace
PROCEDURE SP_MODIF_DESARROLLADOR (
   p_codigo		   	             IN  TFC_DESARROLLADORES.des_codigo%TYPE,
   p_nombre_empresa            IN  TFC_DESARROLLADORES.des_nombre_empresa%TYPE,
   p_representante_legal       IN  TFC_DESARROLLADORES.des_representante_legal%TYPE,
   p_pais              	       IN  TFC_DESARROLLADORES.des_pais%TYPE,
   p_cif			                 IN TFC_DESARROLLADORES.des_cif%TYPE,
   p_direccion  		   	       IN  TFC_DESARROLLADORES.des_direccion%TYPE,
   p_cpostal                   IN  TFC_DESARROLLADORES.des_cpostal%TYPE,
   p_poblacion                 IN  tfc_desarrolladores.des_poblacion%TYPE,
   p_provincia              	 IN  TFC_DESARROLLADORES.des_provincia%TYPE,
   p_telefono                  IN tfc_desarrolladores.des_telefono%TYPE,
   p_fax                       IN tfc_desarrolladores.des_fax%TYPE,
   p_email                     IN tfc_desarrolladores.des_email%TYPE,
   p_aplicaciones_pub          IN tfc_desarrolladores.des_aplicaciones_pub%TYPE,
   RSP              	        OUT VARCHAR2
)

IS

/*****************************************************************************
   Nombre  : SP_MODIF_DESARROLLADOR
   Funcion : Realizamos la modificacion de los datos de los desarrolladores
                   
   Parametros entrada:   p_nombre_empresa ,p_representante_legal ,p_programa,p_pais
                         p_cif,p_direccion,p_cpostal,p_poblacion,p_provincia,p_telefono,
                         p_fax,p_email,p_aplicaciones_pub
   RSP              	 OUT VARCHAR2                
   Parametos salida  :  RSP
						'OK' --> Ejecucion Correcta
                        'ERROR: tipo de error" ejecucion no correcta
******************************************************************************/
/*** variables ****/
p_entrada  VARCHAR2(500);
iexiste INTEGER;
mensaje_error   VARCHAR2 (200);
campo_error 	VARCHAR2(20);
sProcedure VARCHAR2(20); 
/*** Excepciones ****/
eNulo    EXCEPTION;
eFk     EXCEPTION;
ePaisNoExiste EXCEPTION;
numero NUMBER;

BEGIN
-- parametros de entrada 
   p_entrada:=    'p_codigo: '||p_codigo||
                  ',p_nombre_empresa: '||p_nombre_empresa||
                  ', p_representante_legal: '||p_representante_legal||
                  ', p_pais: '||p_pais||
                  ', p_cif: '||p_cif||
                  ',p_direccion: '||p_direccion||
                  ',p_cpostal: '||p_cpostal||
                  ', p_poblacion: '||p_poblacion||
                  ', p_provincia: '||p_provincia||
                  ', p_telefono: '||p_telefono||
                  ', p_fax: '||p_fax||
                  ', p_email: '||p_email||
                  ', p_aplicaciones_pub: '||p_aplicaciones_pub;
                                    
         
  sProcedure:= 'SP_ALTA_DESARROLLADO';
  -- control parametros de entrada 
   IF (p_nombre_empresa IS NULL) THEN 
     campo_error:= 'nombre_empresa';
     RAISE eNulo;
   ELSIF (p_representante_legal IS NULL) THEN 
     campo_error:= 'Representante legal ';
     RAISE eNulo;
	 
	 ELSIF  (p_pais IS NULL) then 
			campo_error:='pais';
			RAISE eNulo;
			ELSIF (p_cif IS NULL) then 
				campo_error:='cif';
				RAISE eNulo;
				ELSIF (p_codigo IS NULL) then 
				campo_error:='codigo';
				RAISE eNulo;
   END IF; 

  -- comprobamos que exista la fila en la tabla de desarrolladores 
   SELECT COUNT (*)   INTO iexiste   FROM TFC_DESARROLLADORES
    WHERE des_CODIGO = p_codigo ;

   IF (iexiste= 0) THEN
       RAISE EFK;
   END IF;
   
   -- comprobamos que exista el pais 
  SELECT COUNT (*)   INTO iexiste   FROM TFC_PAISES
    WHERE PAI_CODIGO = p_pais  ;

   IF (iexiste= 0) THEN
     RAISE ePaisNoExiste;
   END IF;
   --  updateamos la tabla 
   UPDATE TFC_DESARROLLADORES set DES_NOMBRE_EMPRESA = p_nombre_empresa,
                                  DES_REPRESENTANTE_LEGAL = p_representante_legal,
                                  DES_PAIS = p_pais,
                                  DES_CIF = p_cif,
                                  DES_DIRECCION = p_direccion,
                                  DES_CPOSTAL = p_cpostal,
                                  DES_POBLACION = p_poblacion,
                                  DES_PROVINCIA = p_provincia,
                                  DES_TELEFONO = p_telefono,
                                  DES_FAX = p_fax,
                                  DES_EMAIL = p_email
                WHERE des_codigo = p_codigo;
                                  
   
-- ACTUALIZAMOS EL NUMERO DE APLICACIONES QUE TIENE EL DESARROLLADOR 

   SELECT COUNT (*)   INTO iexiste   FROM TFC_DESA_APLICACIONES
    WHERE DEA_DESA = p_codigo ;
   IF (iexiste> 0) THEN
        SELECT des_aplicaciones_pub   into NUMERO  FROM TFC_DESARROLLADORES
        WHERE DES_CODIGO = p_codigo;
        update tfc_Desarrolladores set des_aplicaciones_pub=iexiste
          where des_codigo = p_codigo;
   END IF;
   -- alta tabla de logs 
   RSP:= 'OK';
   RSP:= 'OK:MODIFICACION EFECTUADA ' || p_codigo || '/' ||p_nombre_empresa|| '';
   SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   COMMIT;
   -- control de excepciones 
EXCEPTION
   WHEN eNULO THEN
        RSP:= 'ERROR: el campo ' || campo_error || ' NO PUEDE SER NULO'; 
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
   WHEN EFk THEN
         RSP:= 'ERROR: ' || p_codigo || '/' ||p_nombre_empresa||' EL CODIGO DE DESARROLLADOR  NO  EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   WHEN ePaisNoExiste THEN
         RSP:= 'ERROR: ' || p_codigo|| '/' ||p_pais||' EL CODIGO DE  PAIS PARA ESTE DESARROLLADOR  NO  EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
          
   WHEN OTHERS THEN
        ROLLBACK;
         
          mensaje_error := SUBSTR (SQLERRM, 1, 200);
          RSP:=    'ERROR: ' || mensaje_error;
          SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
              
END SP_MODIF_DESARROLLADOR;
/