create or replace
PROCEDURE SP_MODIF_DISP_USU (
   p_movilusuario	         IN  TFC_DISPOSITIVOS_USUARIO.DIU_MOVILUSUARIO%TYPE,
   p_dispositivo        	 IN  TFC_DISPOSITIVOS_USUARIO.DIU_DISPOSITIVO%TYPE,
   p_soperativo       	   IN  TFC_DISPOSITIVOS_USUARIO.DIU_SOPERATIVO%TYPE,
   p_imei        	         IN  TFC_DISPOSITIVOS_USUARIO.DIU_IMEI%TYPE,
   p_modelo        	       IN  TFC_DISPOSITIVOS_USUARIO.DIU_MODELO%TYPE,
   RSP              	     OUT VARCHAR2
)

IS

/*****************************************************************************
   Nombre  :                SP_MODIF_DISP_USU
   Funcion :				Realizamos la modificiacion de la tabla TFC_DISPOSITIVOS_USUARIO
                   
   Parametros entrada:  p_movilusuario,p_dispositivo,p_soperativo,p_modelo,p_imei,p_modelo
						 
   RSP              	 OUT VARCHAR2                
   Parametos salida  :  RSP
						'OK' --> Ejecucion Correcta
                 'ERROR: tipo de error" ejecucion no correcta
******************************************************************************/
/*** variables ****/
p_entrada  VARCHAR2(500);
iexiste INTEGER;
mensaje_error   VARCHAR2 (200);
campo_error 	VARCHAR2(20);
/*** Excepciones ****/
eNulo    EXCEPTION;
eFk     EXCEPTION;
eNoExiste EXCEPTION;
eNoExisteDispositivo EXCEPTION;
eNoExisteSistema EXCEPTION;
eNoExisteModelo EXCEPTION;
sProcedure VARCHAR2(20);
BEGIN
	-- parametros de entrada 
   p_entrada:=    'p_movilusuario: '||p_movilusuario||
                  ',p_dispositivo: '||p_dispositivo||
                  ', p_soperativo: '||p_soperativo||
                  ', p_imei: '||p_imei||
                  ', p_modelo: '||p_modelo;
                  
         
  sProcedure:= 'SP_MODIF_DISP_USU';
  -- control parametros de entrada 
   IF (p_dispositivo IS NULL) THEN 
     campo_error:= 'dispositivo';
     RAISE eNulo;
   ELSIF (p_soperativo IS NULL) THEN 
     campo_error:= 'Sistema Operativo';
     RAISE eNulo;
	 
	 ELSIF  (p_modelo IS NULL) then 
			campo_error:='Modelo';
			RAISE eNulo;
				ELSIF (p_movilusuario IS NULL) then 
				campo_error:='movilusuario';
				RAISE eNulo;
        ELSIF (p_imei IS NULL) then
        campo_error:='Imei';
        RAISe eNULO;
   END IF; 

   
    
   -- comprobamos que exista el dispositivo en la tabla de dispositivos 
   SELECT COUNT (*)   INTO iexiste   FROM TFC_DISPOSITIVOS
   WHERE DIS_codigo = p_dispositivo;
   IF (iexiste= 0) THEN
     RAISE eNoExisteModelo;
   END IF;
   
   --comprobamos que exista el sistema operativo 
   SELECT COUNT (*)   INTO iexiste   FROM TFC_SISTEMAS_OPERATIVOS
      WHERE MSO_CODIGO = p_soperativo;
   IF (iexiste= 0) THEN
     RAISE eNoExisteSistema;
   END IF;
   
   --comprobamos que exista el modelo
   SELECT COUNT (*)   INTO iexiste   FROM TFC_MODELOS_MOVIL
      WHERE MOD_MODELO = p_modelo;
   IF (iexiste= 0) THEN
     RAISE eNoExisteModelo;
   END IF;
   
  -- comprobamos que exista el dispositivo de usuario 
   SELECT COUNT (*)   INTO iexiste   FROM TFC_DISPOSITIVOS_USUARIO
    WHERE DIU_IMEI = p_imei;
    
   IF (iexiste=0) THEN
     RAISE eFk;
   END IF;
   
  -- updateamos dispositivos de usuario 
  UPDATE TFC_DISPOSITIVOS_USUARIO SET DIU_SOPERATIVO = p_soperativo,
          DIU_MODELO = p_modelo,
          DIU_DISPOSITIVO = p_dispositivo
    WHERE DIU_IMEI = p_imei;
    

	-- alta logs 
   RSP:= 'OK';
   RSP:= 'OK:MODIFICACION DISPOSITIVO USUARIO ' || p_MOVILUSUARIO ||  '';
   SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   COMMIT;
   -- control de excepciones 
EXCEPTION
   WHEN eNULO THEN
        RSP:= 'ERROR: el campo ' || campo_error || ' NO PUEDE SER NULO'; 
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
   WHEN EFk THEN
         RSP:= 'ERROR: ' || p_movilusuario || ' EL DISPOSITIVO USUARIO  NO EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
    
   WHEN eNoExisteDispositivo THEN
         RSP:= 'ERROR: ' || p_movilusuario || '/' ||p_dispositivo||' EL DISPOSITIVO  NO EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);   
  WHEN eNoExisteSistema THEN
         RSP:= 'ERROR: ' || p_movilusuario || '/' ||p_soperativo||' EL SISTEMA OPERATIVO  NO EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);   
  WHEN eNoExisteModelo THEN
         RSP:= 'ERROR: ' || p_movilusuario || '/' ||p_modelo||' EL MODELO  NO EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);   
   WHEN OTHERS THEN
        ROLLBACK;
         
          mensaje_error := SUBSTR (SQLERRM, 1, 200);
          RSP:=    'ERROR: ' || mensaje_error;
          SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
              
END SP_MODIF_DISP_USU;
/