create or replace
PROCEDURE SP_MODIF_PAISES_APL (
   p_codigo		   	         IN  TFC_PAISES_APLICACIONES.APP_CODIGO%TYPE,
   p_version        	     IN  TFC_PAISES_APLICACIONES.APP_VERSION%TYPE,
   p_pais       	         IN  TFC_PAISES_APLICACIONES.APP_PAIS%TYPE,
   p_divisa       	       IN  TFC_PAISES_APLICACIONES.APP_DIVISA%TYPE,
   p_precio  			         IN TFC_PAISES_APLICACIONES.APP_PRECIO%TYPE,
   RSP              	     OUT VARCHAR2
)

IS

/*****************************************************************************
   Nombre  : SP_MODIF_PAISES_APL
   Funcion : Realizamos un MODIFICACION en la tabla TFC_PAISES_APLICACIONES
                   
   Parametros entrada:   p_version ,p_fecha_alta ,p_pais,p_divisa,p_precio
						 
   RSP              	 OUT VARCHAR2                
   Parametos salida  :  RSP
						'OK' --> Ejecucion Correcta
                 'ERROR: tipo de error" ejecucion no correcta
******************************************************************************/
/*** variables ****/
p_entrada  VARCHAR2(500);
iexiste INTEGER;
mensaje_error   VARCHAR2 (200);
campo_error 	VARCHAR2(20);
/*** Excepciones ****/
eNulo    EXCEPTION;
eFk     EXCEPTION;
eNoExiste EXCEPTION;
eNoExistePais EXCEPTION;
eNoExisteDivisa EXCEPTION;
sProcedure VARCHAR2(20);
BEGIN
  -- parametros de entrada 
   p_entrada:=    'p_codigo: '||p_codigo||
                  ',p_version: '||p_version||
                  ', p_pais: '||p_pais||
                  ', p_divisa: '||p_divisa||
                  ', p_precio: '||p_precio;
                  
         
  sProcedure:= 'SP_MODIF_PAISES_APL';
  -- control parametros de entrada 
   IF (p_version IS NULL) THEN 
     campo_error:= 'version';
     RAISE eNulo;
   ELSIF (p_pais IS NULL) THEN 
     campo_error:= 'Pais';
     RAISE eNulo;
	 
	 ELSIF  (p_divisa IS NULL) then 
			campo_error:='divisa';
			RAISE eNulo;
			ELSIF (p_precio IS NULL) then 
				campo_error:='Precio';
				RAISE eNulo;
				ELSIF (p_codigo IS NULL) then 
				campo_error:='codigo';
				RAISE eNulo;
   END IF; 

     
  -- comprobamos que exista para la aplicacion/version el pais/divisa
   SELECT COUNT (*)   INTO iexiste   FROM TFC_PAISES_APLICACIONES
    WHERE APP_CODIGO = p_codigo and APP_VERSION=p_version and APP_PAIS=p_pais AND app_divisa = p_divisa ;

   IF (iexiste= 0) THEN
     RAISE eNoExiste;
   END IF;
   
   -- MODIFICACIONES
   UPDATE TFC_PAISES_APLICACIONES SET APP_PRECIO = p_precio 
   WHERE APP_CODIGO=p_codigo
   AND APP_VERSION = p_version
   AND APP_PAIS = p_pais
   AND APP_DIVISA = p_divisa;
   
	-- alta log 
 
   RSP:= 'OK:MODIF PAIS/DIVISA EFECTUADA ' || p_codigo || '/' ||p_version|| '/' ||p_pais|| '/' ||p_divisa|| '';
   SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   COMMIT;
   -- control de excepciones 
EXCEPTION
   WHEN eNULO THEN
        RSP:= 'ERROR: el campo ' || campo_error || ' NO PUEDE SER NULO'; 
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
   WHEN eNoExiste THEN
         RSP:= 'ERROR: ' || p_codigo || '/' ||p_version||' EL PAIS/DIVISA PARA ESTA APLICACION/VERSION NO EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
    
   WHEN OTHERS THEN
        ROLLBACK;
         
          mensaje_error := SUBSTR (SQLERRM, 1, 200);
          RSP:=    'ERROR: ' || mensaje_error;
          SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
              
END SP_MODIF_PAISES_APL;
/