create or replace
PROCEDURE SP_MODIF_SISTEMA_APL (
   p_codigo		   	         IN  TFC_SISTEMA_APLICACIONES.SOP_CODIGO%TYPE,
   p_version        	     IN  TFC_SISTEMA_APLICACIONES.SOP_VERSION%TYPE,
   p_soperativo       	   IN  TFC_SISTEMA_APLICACIONES.SOP_soperativo%TYPE,
   p_enlacef       	       IN  TFC_SISTEMA_APLICACIONES.SOP_enlacef%TYPE,
   p_medida  			         IN TFC_SISTEMA_APLICACIONES.SOP_medida%TYPE,
 
   RSP              	     OUT VARCHAR2
)

IS

/*****************************************************************************
   Nombre  :  SP_MODIF_SISTEMA_APLICACIONES
   Funcion :  Realizamos un MODIFICACION en la tabla TFC_SISTEMA_APLICACIONES
                   
   Parametros entrada:   p_codigo,p_version ,p_soperativo,p_enlacef,p_medida
						 
   RSP              	 OUT VARCHAR2                
   Parametos salida  :  RSP
						'OK' --> Ejecucion Correcta
                 'ERROR: tipo de error" ejecucion no correcta
******************************************************************************/
/*** variables ****/
p_entrada  VARCHAR2(500);
iexiste INTEGER;
mensaje_error   VARCHAR2 (200);
campo_error 	VARCHAR2(20);
/*** Excepciones ****/
eNulo    EXCEPTION;
eFk     EXCEPTION;
eNoExiste EXCEPTION;
eNoExistesoperativo EXCEPTION;

sProcedure VARCHAR2(20);
BEGIN

   -- parametros de entrada 
   p_entrada:=    'p_codigo: '||p_codigo||
                  ',p_version: '||p_version||
                  ', p_soperativo: '||p_soperativo||
                  ', p_enlacef: '||p_enlacef||
                  ', p_medida: '||p_medida;

         
  sProcedure:= 'SP_MODIF_SISTEMA_APL';
  -- control parametros de entrada 
   IF (p_version IS NULL) THEN 
     campo_error:= 'version';
     RAISE eNulo;
   ELSIF (p_soperativo IS NULL) THEN 
     campo_error:= 'soperativo';
     RAISE eNulo;
	 
	 ELSIF  (p_enlacef IS NULL) then 
			campo_error:='enlacef';
			RAISE eNulo;
			ELSIF (p_medida IS NULL) then 
				campo_error:='medida';
				RAISE eNulo;
				ELSIF (p_codigo IS NULL) then 
				campo_error:='codigo';
				RAISE eNulo;
   END IF; 

  -- comprobamos que exista es aplicacion
   SELECT COUNT (*)   INTO iexiste   FROM TFC_APLICACION
    WHERE APL_CODIGO = p_codigo and APL_VERSION=p_version;
   IF (iexiste= 0) THEN
     RAISE eNoExiste;
   END IF;
   -- comprobamos que existe el sistema que queremos modificar en la tabla de sistemas aplicaciones   
   SELECT COUNT (*)   INTO iexiste   FROM TFC_SISTEMA_APLICACIONES
   WHERE SOP_CODIGO = p_codigo 
   AND SOP_VERSION = p_version
   AND SOP_SOPERATIVO = p_soperativo;
   IF (iexiste= 0) THEN
     RAISE eFk;
   END IF;
   

   -- modificacion 
   
   UPDATE TFC_SISTEMA_APLICACIONES SET SOP_ENLACEF=p_enlacef,SOP_MEDIDA=p_medida 
   WHERE SOP_CODIGO = p_codigo 
   AND SOP_VERSION = p_version
   AND SOP_SOPERATIVO = p_soperativo;
   -- alta logs 
   RSP:= 'OK';
   RSP:= 'OK:MODIFICAICON SOPERATIVO APLICACION EFECTUADA ' || p_codigo || '/' ||p_version|| '/' ||p_soperativo|| '';
   SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   COMMIT;
   -- control de excepciones 
EXCEPTION
   WHEN eNULO THEN
        RSP:= 'ERROR: el camp ' || campo_error || ' NO PUEDE SER NULO'; 
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
             
   WHEN EFk THEN
         RSP:= 'ERROR: ' || p_codigo || '/' ||p_version||' EL Codigo/Version/Sistema Operativo  PARA ESTA APLICACION/VERSION NO EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   WHEN eNoExiste THEN
         RSP:= 'ERROR: ' || p_codigo || '/' ||p_version||' EL CODIGO DE APLICACION/VERSION NO EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);   
   WHEN OTHERS THEN
        ROLLBACK;
          mensaje_error := SUBSTR (SQLERRM, 1, 200);
          RSP:=    'ERROR: ' || mensaje_error;
          SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
              
END SP_MODIF_SISTEMA_APL;
/