create or replace
PROCEDURE SP_MODIF_USUARIOS (
   p_movilusuario	         IN  TFC_USUARIOS.USU_MOVILUSUARIO%TYPE,
   p_operador        	     IN  TFC_USUARIOS.USU_OPERADOR%TYPE,
   p_pais       	         IN  TFC_USUARIOS.USU_PAIS%TYPE,
   p_email        	       IN  TFC_USUARIOS.USU_EMAIL%TYPE,
   p_nombre        	       IN  TFC_USUARIOS.USU_NOMBRE%TYPE,
   p_direccion             IN  TFC_USUARIOS.USU_DIRECCION%TYPE,
   p_cpostal               IN  TFC_USUARIOS.USU_CPOSTAL%TYPE,
   p_poblacion             IN  TFC_USUARIOS.USU_POBLACION%TYPE,
   p_provincia             IN  TFC_USUARIOS.USU_PROVINCIA%TYPE,
   P_nif                   IN  TFC_USUARIOS.USU_NIF%TYPE,
   p_cuenta                IN  TFC_USUARIOS.USU_CUENTA%type,
   
   RSP              	     OUT VARCHAR2
)

IS

/*****************************************************************************
   Nombre  :  SP_MODIF_USUARIOS
   Funcion :	Realizamos la modificacion de los datos de 
              la tabla  TFC_USUARIOS
                   
   Parametros entrada:  p_movilusuario,p_operador,p_pais,p_email,p_nombre,
                        p_direccion,p_cpostal,p_poblacion,p_provincia,
                        p_nif,p_cuenta
      
   Parametos salida  :  RSP
						'OK'+ mensaje  --> Ejecucion Correcta
            'ERROR: tipo de error" ejecucion no correcta
******************************************************************************/
/*** variables ****/
p_entrada  VARCHAR2(500);
iexiste INTEGER;
mensaje_error   VARCHAR2 (200);
campo_error 	VARCHAR2(20);

/*** Excepciones ****/
eNulo    EXCEPTION;
eFk     EXCEPTION;
eNoExiste EXCEPTION;
eNoExistePais EXCEPTION;
eNoExisteOperador EXCEPTION;
sProcedure VARCHAR2(20);
BEGIN
	-- parametros de entrada 
   p_entrada:=    'p_movilusuario: '||p_movilusuario||
                  ',p_operador: '||p_operador||
                  ', p_pais: '||p_pais||
                  ',p_mombre: '||p_nombre||
                  ', p_email: '||p_email||
                  ',p_direccion: '||p_direccion||
                  ',p_cpostal: '||p_cpostal||
                  ',p_poblacion: '||p_poblacion||
                  ',p_provincia: '||p_provincia||
                  ',p_nif: '||p_nif||
                  ',p_cuenta: '||p_cuenta;
                
                  
         
  sProcedure:= 'SP_MODIF_USUARIOS';
   
   -- validamos los campos necesarios 
   IF (p_operador IS NULL) THEN 
      campo_error:= 'Operador';
      RAISE eNulo;
   ELSIF (p_pais IS NULL) THEN 
     campo_error:= 'Pais';
     RAISE eNulo;
   ELSIF  (p_email IS NULL) then 
			campo_error:='email';
			RAISE eNulo;
			ELSIF (p_movilusuario IS NULL) then 
		 		campo_error:='Movil Usuario';
			RAISE eNulo;
      	ELSIF (p_cuenta IS NULL) then 
		 		campo_error:='Cuenta Usuario';
			RAISE eNulo;
   END IF; 

   
   -- Controlamos excepciones  
   -- comprobamos que exista el pais en la tabla de  paises
   SELECT COUNT (*)   INTO iexiste   FROM TFC_PAISES
      WHERE pai_codigo = p_pais;
   IF (iexiste= 0) THEN
     RAISE eNoExistePais;
   END IF;
   -- comprobamos que exista el operador telefonico
   SELECT COUNT (*)   INTO iexiste   FROM TFC_OPERADORES_TELEFONICOS
      WHERE OPE_CODIGO = p_operador;
   IF (iexiste= 0) THEN
     RAISE eNoExisteOperador;
   END IF;
   
  -- comprobamos que NO EXISTE el movil de usuario que intentamos dar de alta 
   SELECT COUNT (*)   INTO iexiste   FROM TFC_USUARIOS
      WHERE USU_MOVILUSUARIO = p_movilusuario;
   IF (iexiste= 0) THEN
     RAISE eFk;
   END IF;
   
   -- modificacion datos usuario 
   UPDATE TFC_USUARIOS  SET USU_OPERADOR = p_operador,
                            USU_PAIS = p_pais,
                            USU_EMAIL=p_email,
                            USU_NOMBRE = p_nombre,
                            USU_DIRECCION=p_direccion,
                            USU_CPOSTAL=p_cpostal,
                            USU_POBLACION = p_poblacion,
                            USU_PROVINCIA=p_provincia,
                            USU_NIF=p_nif,
                            USU_CUENTA=p_cuenta
    WHERE USU_MOVILUSUARIO = p_movilusuario;
    
   -- alta logs 
   RSP:= 'OK:MODIFICACION USUARIO ' || p_MOVILUSUARIO ||  '';
   SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   COMMIT;
   -- control de excepciones 
EXCEPTION
   WHEN eNULO THEN
        RSP:= 'ERROR: el campo ' || campo_error || ' NO PUEDE SER NULO'; 
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
   WHEN EFk THEN
         RSP:= 'ERROR: ' || p_movilusuario || 'EL USUARIO QUE INTENTA MODIFICAR NO EXISTE ';           
        SP_ALTA_LOGS( sProcedure, p_entrada, 'RSP: '||RSP);
    
   WHEN eNoExistePais THEN
         RSP:= 'ERROR: ' || p_movilusuario || '/' ||p_pais||' EL PAIS NO EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);   
  WHEN eNoExisteOperador THEN
         RSP:= 'ERROR: ' || p_movilusuario || '/' ||p_operador||' EL OPERADOR NO EXISTE';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);   
   WHEN OTHERS THEN
        ROLLBACK;
          mensaje_error := SUBSTR (SQLERRM, 1, 200);
          RSP:=    'ERROR: ' || mensaje_error;
          SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
              
END SP_MODIF_USUARIOS;
/