create or replace
PROCEDURE SP_ALTA_DESCARGAS (
   p_codigo		   	         IN  TFC_DESCARGAS_APLICACIONES.DES_codigo%TYPE,
   p_version        	     IN  TFC_DESCARGAS_APLICACIONES.DES_version%TYPE,
   p_fecha                 IN  TFC_DESCARGAS_APLICACIONES.DES_FECHA%TYPE,
   p_divisa    	           IN  TFC_DESCARGAS_APLICACIONES.DES_divisa%TYPE,
   p_modo_pago    	       IN  TFC_DESCARGAS_APLICACIONES.DES_modo_pago%TYPE,
   p_pais			             IN  TFC_DESCARGAS_APLICACIONES.DES_pais%TYPE,
   p_imei       	         IN  TFC_DESCARGAS_APLICACIONES.DES_imei%TYPE,
   p_operador			         IN  TFC_DESCARGAS_APLICACIONES.DES_operador%TYPE,
   RSP              	     OUT VARCHAR2
)

IS

/*****************************************************************************
   Nombre  :   SP_ALTA_DESCARGAS
   Funcion :	Realizamos la modificacion de la tabla TFC_IDIOMAS_APLICACIONES
                   
   Parametros entrada:   p_codigo,p_version ,p_fecha ,p_divisa,p_modo_pago,
                         p_pais,p_imei,p_operador 
						 
   RSP              	 OUT VARCHAR2                
   Parametos salida  :  RSP
						'OK' --> Ejecucion Correcta
                 'ERROR: tipo de error" ejecucion no correcta
******************************************************************************/
/*** variables ****/
p_entrada  VARCHAR2(500);
iexiste INTEGER;
mensaje_error   VARCHAR2 (200);
campo_error 	VARCHAR2(20);
p_precio1 NUMBER(16,2);
/*** Excepciones ****/
eNulo             EXCEPTION;
eFk               EXCEPTION;
eFka              EXCEPTION;
eNoExisteOperador EXCEPTION;
eNoExistePais     EXCEPTION;
sProcedure        VARCHAR2(20);
NUMERODISTINTO    NUMBER;
anio              NUMBER;
p1                VARCHAR2(50);
type r_cursor IS REF CURSOR;

CUR r_cursor;
desarrollador1       NUMBER;
MEDIA                NUMBER(16,2);
NUMEROTOTALDESCARGAS NUMBER;
NUMERODESCARGAS      NUMBER;
TOTALDESCARGAS       NUMBER;
TOTALIMPORTE         NUMBER(16,2);
NUMEROUSUARIOS       NUMBER;
TOTALDESCARGASU      NUMBER;
NUMERO5              NUMBER;
NUMERO7              NUMBER;

BEGIN
	-- parametros de entrada 
   p_entrada:=    'p_codigo: '||p_codigo||
                  ',p_version: '||p_version||
                  ', p_fecha: '||p_fecha||
                  ', p_divisa: '||p_divisa||
                  ', p_modo_pago: '||p_modo_pago||
                  ', p_pais: '||p_pais||
                  ', p_imei: '||p_imei||
                  ', p_operador: '||p_operador;
         
  sProcedure:= 'SP_ALTA_DESCARGAS';
  -- control parametros de entrada 
  
   select extract(year from sysdate) INTO anio from dual;
  
   IF (p_version IS NULL) THEN 
     campo_error:= 'version';
     RAISE eNulo;
   ELSIF (p_divisa IS NULL) THEN 
     campo_error:= 'Divisa';
     RAISE eNulo;
	 ELSIF  (p_modo_pago IS NULL) then 
			campo_error:='Modo Pago';
			RAISE eNulo;
			ELSIF (p_imei IS NULL) then 
				campo_error:='Imei';
				RAISE eNulo;
				ELSIF (p_codigo IS NULL) then 
				campo_error:='codigo';
				RAISE eNulo;
        ELSIF (p_fecha IS NULL) then 
				campo_error:='Fecha';
				RAISE eNulo;
        ELSIF (p_pais IS NULL) then 
				campo_error:='pais';
				RAISE eNulo;
        ELSIF (p_operador IS NULL) then 
				campo_error:='operador';
				RAISE eNulo;
   END IF; 

   
   --Comprobamos que exista la aplicacion y est activa 
    SELECT COUNT (*)   INTO iexiste   FROM TFC_APLICACION
    WHERE APL_CODIGO = p_codigo and APL_VERSION=p_version and APL_ACTIVA=0;
     IF (iexiste= 0) THEN
       RAISE eFka;
     END IF;
   
  -- comprobamos que exista el operador telefonico 
   SELECT COUNT (*)   INTO iexiste   FROM TFC_OPERADORES_TELEFONICOS
    WHERE OPE_CODIGO = p_operador;
    IF (iexiste= 0) THEN
       RAISE eNoExisteOperador;
    END IF;
    
   -- comprobamos que exista la aplicacion para ese pais y buscamos el precio 
   -- a aplicar en la descarga 
   
    SELECT COUNT (*)   INTO iexiste   FROM TFC_PAISES_APLICACIONES 
    where APP_CODIGO = p_codigo
    AND APP_VERSION = p_version
    AND APP_PAIS = p_pais
    AND APP_DIVISA = p_divisa;
    IF (iexiste= 0) THEN
       RAISE eFk;
    ELSE 
		-- buscamos el precio a aplicar en la descarga
       SELECT APP_PRECIO  INTO p_precio1   FROM TFC_PAISES_APLICACIONES 
        where APP_CODIGO = p_codigo
        AND APP_VERSION = p_version
        AND APP_PAIS = p_pais
        AND APP_DIVISA = p_divisa;
    
    END IF;
   
   -- COMPROBAMOS SI EL USUARIO HA HECHO ALGUNA DESCARGA EN ESE PAIS EN EL AO DE LA DESCARGA , SI NO LA HA HECHO SUMAMOS 1 A TFC_ESTADISTICA5
  
   	   NUMERO5:=0;
       SELECT COUNT(*) INTO iexiste    FROM TFC_DESCARGAS_APLICACIONES 
       WHERE DES_FECHA >= to_date('01'||anio ,'mm/yy') AND DES_FECHA <=to_date('12'||anio,'mm/yy') 
        AND  DES_PAIS = p_pais
        AND DES_IMEI  = p_imei;
         IF (iexiste= 0) THEN
            NUMERO5:=1;
         END IF ;
    
    
   -- COMPROBAMOS SI EN ESE USUARIO HA HECHO ALGUNA DESCARGA EN ESE PAIS , SI NO LA HA HECHO SUMAMOS 1 A TFC_ESTADISTICA5
   
   	   NUMERO7:=0;
       SELECT COUNT(*) INTO iexiste    FROM TFC_DESCARGAS_APLICACIONES 
        WHERE DES_FECHA >= to_date('01'||anio ,'mm/yy') AND DES_FECHA <=to_date('12'||anio,'mm/yy') 
        AND DES_PAIS = p_pais
        AND DES_CODIGO  = p_codigo
        AND DES_VERSION= p_version;
         IF (iexiste= 0) THEN
            NUMERO7:=1;
         END IF ;
    
   
   
   -- damos de alta la descarga 
   INSERT INTO TFC_DESCARGAS_APLICACIONES(DES_CODIGO, DES_VERSION, DES_FECHA,DES_PRECIO,DES_DIVISA,DES_MODO_PAGO,DES_PAIS,DES_IMEI,DES_OPERADOR)
   VALUES                                (p_codigo,   p_version,   p_fecha, p_precio1,  p_divisa, p_modo_pago,  p_pais, p_imei,     p_operador);
   --damos de alta la tabla de log 
   RSP:= 'OK:ALTA DESCARGA EFECTUADA ' || p_codigo || '/' ||p_version|| '';
   SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
   
   
   
 -- select extract(year from sysdate) INTO anio from dual;
  
   
  -- actualizamos las estadisticas y otras tablas --
  -- TFC_ESTADISTICA1: Nmero total de descargas de la plataforma hasta el da actual
  --                   Nmero total de euros que la plataforma genere en descargas hasta el momento
  
  -- comprobamos que exista el registro en tfc_Estadistica1 y si no existe lo creamos.
   SELECT COUNT(*) into iexiste FROM TFC_ESTADISTICA1;
   IF (iexiste)= 0 THEN 
      INSERT into TFC_ESTADISTICA1 (E1_TOTALDESCARGAS,E1_TOTALIMPORTE) VALUES(0,0);
   END IF ;
   -- seleccionamos la fila de la tabla y actualizamos el contenido sumando 1 a la descarga y acumulando el precio al importe 
   SELECT E1_TOTALDESCARGAS ,E1_TOTALIMPORTE INTO TOTALDESCARGAS, TOTALIMPORTE  FROM TFC_ESTADISTICA1;
   
   UPDATE tfc_estadistica1 set E1_TOTALDESCARGAS = TOTALDESCARGAS + 1 ,
                              E1_TOTALIMPORTE =  TOTALIMPORTE + p_precio1;
  
  
  --TFC_ESTADISTICA2: Dado un ao en concreto debemos de poder obtener el nmero medio de aplicaciones descargas por un usuario.
  -- Comprobamos que exista la fila por ao  en la tabla de estadisticas 
    
    SELECT COUNT(*) INTO iexiste FROM TFC_ESTADISTICA2
      WHERE   E2_ANY1 = anio
	    AND    E2_IMEI = p_imei;
      IF (iexiste)= 0 then 
         INSERT INTO TFC_ESTADISTICA2 (E2_ANY1,E2_MEDIADESCARGAS,E2_IMEI,E2_DESCARGAS) VALUES(anio,0,p_imei,0);
      END IF ;
  
 
   --  SELECT COUNT(distinct DES_IMEI) INTO NUMERODISTINTO FROM TFC_DESCARGAS_APLICACIONES
   --    WHERE des_fecha >= to_date('01'||anio ,'mm/yy') AND DES_FECHA <=to_date('12'||anio,'mm/yy');
   
      
  --  SELECT COUNT(*)  INTO NUMEROTOTALDESCARGAS FROM TFC_DESCARGAS_APLICACIONES
  --   WHERE des_fecha >= to_date('01'||anio ,'mm/yy') AND DES_FECHA <=to_date('12'||anio,'mm/yy');
      
      SELECT E2_DESCARGAS INTO TOTALDESCARGASU  FROM TFC_ESTADISTICA2
      WHERE   E2_ANY1 = anio
	    AND    E2_IMEI = p_imei;
      
      --NUMERO TOTAL DE DESCARGAS QUE HEMOS SELECCIONADO EN LA SELECT DE LA TFC_ESTADISTICA1 PARA ACTUALIZARLA
      
      TOTALDESCARGAS:= TOTALDESCARGAS  + 1 ;
      TOTALDESCARGASU := TOTALDESCARGASU + 1 ;
      
      MEDIA:=TOTALDESCARGAS/TOTALDESCARGASU ;
        
       UPDATE TFC_ESTADISTICA2 SET e2_mediadescargas = media,
	                               e2_descargas = totaldescargasu
          WHERE e2_any1 = anio
		  AND E2_IMEI = p_imei;
  
  --TFC_ESTADISTICA3: Actulizamos el numero de descargas del desarrollador de esta descarga.
  --                  Con esta informacion generamos la tabal TFC_ESTADISTICA3 que realizando -
  --					la Select correspondiente nos indicar el desarrollador con mas descargas :
  --					Dado un ao en concreto debemos de saber el desarrollador que tenga el nmero mximo de descargas, 
  --					sumando todas les descargas de todas sus aplicaciones que se hayan realizado ese ao, as como el nmero en concreto.
  
  -- Buscamos los desarrolladores de la aplicacion descargada,lo hago con un cursor ya que puede haber varios 
  -- desarrolladores que participen en una aplicacion  , este cursor sirve para actualizar varias tablas estadsticas.
  
  OPEN CUR FOR 
    select DEA_DESA FROM TFC_DESA_APLICACIONES
    WHERE  DEA_CODIGO = p_codigo
    AND DEA_VERSION = p_version;
                               
   LOOP
     FETCH CUR INTO desarrollador1;
     EXIT WHEN CUR%NOTFOUND;
       SELECT COUNT(*) INTO iexiste from TFC_ESTADISTICA3 
        WHERE E3_ANY1 = anio
        AND  E3_DESARROLLADOR = desarrollador1 ;
        IF (iexiste)= 0 then 
           INSERT into TFC_ESTADISTICA3 (E3_ANY1,E3_DESARROLLADOR,E3_NUMERODESCARGAS) VALUES(anio,desarrollador1,0);
        END IF ;
     -- actualizamos la tabla TFC_ESTADISTICA3, aumentando en 1 el numero de descargas 
    
     UPDATE tfc_estadistica3 SET E3_NUMERODESCARGAS = E3_NUMERODESCARGAS  + 1 
       WHERE  E3_ANY1 = anio
       AND  E3_DESARROLLADOR = desarrollador1 ;
  
     
     -- TFC_ESTADISTICA4 : Dado un ao en concreto debemos de poder obtener la aplicacin que ms dinero 
	 --                    ha recaudado en descargas as como su desarrollador
     -- comprobamos que exista el registro en TFC_ESTADISTICA4 , si no existe lo creamos 
	 
      SELECT COUNT (*) INTO iexiste from TFC_ESTADISTICA4 
        WHERE E4_ANY1 = anio
        AND  E4_APLICACION=p_codigo
        AND  e4_version =p_version
        AND  E4_DESARROLLADOR = desarrollador1 ;
        IF (iexiste)= 0 THEN 
          INSERT into TFC_ESTADISTICA4 (E4_ANY1,E4_APLICACION,E4_vERSION,E4_DESARROLLADOR,E4_IMPORTE) VALUES(anio,p_codigo,p_version,desarrollador1,0);
        END IF ;
  
    -- actualizmos la fila incrementando el importe en el precio por el que se ha realizado la descarga.
        UPDATE tfc_estadistica4 SET E4_importe  = E4_importe + p_precio1 
            WHERE  E4_ANY1 = anio
            AND  E4_APLICACION=p_codigo
            AND  E4_version =p_version
            AND  E4_DESARROLLADOR = desarrollador1 ;
     
     
   END LOOP;  
   CLOSE CUR;  
  
  
    -- TFC_ESTADISTICA5: Dado un ao en concreto y un pas, debemos de poder obtener el nmero 
	--                   de usuarios diferentes que han hecho como mnimo una descarga.
	
	-- Comprobamos que exista la fila en la tabla , si no existe la creamos.
    IF NUMERO5 > 0 THEN 
      SELECT COUNT (*) INTO iexiste from TFC_ESTADISTICA5 
        WHERE E5_ANY1 = anio
        AND  E5_PAIS = p_pais;
        IF (iexiste)= 0 then 
            INSERT into TFC_ESTADISTICA5(E5_ANY1,E5_PAIS,E5_NUMEROUSUARIOS) VALUES(anio,p_pais,0);
         END IF ;
      --SUPONEMOS QUE CADA USUARIOS SOLO TIENE UN TELEFONO.IMEI
     -- SELECT COUNT(distinct DES_IMEI) INTO NUMERODISTINTO FROM TFC_DESCARGAS_APLICACIONES
     --  WHERE DES_PAIS =p_pais;
       SELECT  E5_NUMEROUSUARIOS  INTO NUMERODISTINTO FROM TFC_ESTADISTICA5
         WHERE    E5_ANY1 = anio
         AND E5_PAIS = p_pais;
 
      -- actualizamos la tabla TFC_ESTADISTICA5    
      UPDATE tfc_estadistica5 SET E5_NUMEROUSUARIOS  =NUMERODISTINTO + 1 
          WHERE   E5_ANY1 = anio
          AND  E5_PAIS = p_pais;
    END IF ;
    
   -- TFC_ESTADISIICA6 :	Dado un ao en concreto y un pas, debemos de poder obtener los
   --ingresos totales generados por los usuarios registrados en el pas al realizar las descargas.
      SELECT COUNT (*) INTO iexiste FROM TFC_ESTADISTICA6 
        WHERE  E6_ANY1 = anio
        AND  E6_PAIS = p_pais;
        IF (iexiste)= 0 then 
            INSERT into TFC_ESTADISTICA6(E6_ANY1,E6_PAIS,E6_IMPORTE) VALUES(anio,p_pais,0);
         END IF ;
       SELECT  E6_IMPORTE  INTO TOTALIMPORTE FROM TFC_ESTADISTICA6
         WHERE    E6_ANY1 = anio
         AND E6_PAIS = p_pais;
         UPDATE tfc_estadistica6 SET E6_IMPORTE  = TOTALIMPORTE + p_precio1
              WHERE     E6_ANY1 = anio
              AND  E6_PAIS = p_pais;
 
   -- TFC_ESTADISTICA7 : Dado un ao en concreto y un pas, debemos de poder obtener 
   --                    el nmero de aplicaciones diferentes descargadas como mnimo una vez.
   -- Comprobamos que exista la fila    
   SELECT COUNT (*) INTO iexiste FROM TFC_ESTADISTICA7
        WHERE  E7_ANY1 = anio
        AND  E7_PAIS = p_pais;
        IF (iexiste)= 0 then 
            INSERT into TFC_ESTADISTICA7(E7_ANY1,E7_PAIS,E7_NUMEROAPLICACIONES) VALUES(anio,p_pais,0);
         END IF ;
      
     SELECT COUNT(distinct DES_CODIGO) INTO NUMERODISTINTO FROM TFC_DESCARGAS_APLICACIONES
      WHERE DES_PAIS =p_pais;
      
    
      UPDATE tfc_estadistica7 SET  E7_NUMEROAPLICACIONES  =NUMERODISTINTO
          WHERE  E7_ANY1 = anio
          AND  E7_PAIS = p_pais;
   
   
   
   -- ACTUALIZAMOS OTROS DATOS DE LAS TABLAS DE LA BD
   -- Numero descargas total en tfc_aplicaciones
   SELECT APL_NUMERODESCARGAS INTO NUMERODESCARGAS FROM TFC_APLICACION  
      WHERE  APL_CODIGO = p_codigo
      AND APL_VERSION = p_version;
      
   UPDATE TFC_APLICACION SET APL_NUMERODESCARGAS =  NUMERODESCARGAS + 1 
      WHERE  APL_CODIGO = p_codigo
      AND APL_VERSION = p_version;
   
   -- Numero descargas total en tfc_paises_aplicaciones
   
   SELECT APP_NUMERODESCARGAS INTO NUMERODESCARGAS FROM TFC_PAISES_APLICACIONES 
    WHERE  APP_CODIGO = p_codigo
     AND APP_VERSION = p_version
     AND APP_PAIS = p_pais
     and APP_DIVISA = p_divisa;
     
  UPDATE TFC_PAISES_APLICACIONES SET APP_NUMERODESCARGAS =  NUMERODESCARGAS + 1 
     WHERE  APP_CODIGO = p_codigo
     AND APP_VERSION = p_version
     AND APP_PAIS = p_pais
     and APP_DIVISA = p_divisa;
  
   COMMIT;
   
EXCEPTION
   WHEN eNULO THEN
        RSP:= 'ERROR: el campo ' || campo_error || ' NO PUEDE SER NULO'; 
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
    
   WHEN eNoExisteOperador THEN
         RSP:= 'ERROR: ' || p_codigo || '/' ||p_version|| '/' ||p_operador|| ' EL OPERADOR TELEFONICO NO EXISTE ';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);   
   WHEN eFk THEN
         RSP:= 'ERROR: ' || p_codigo || '/' ||p_version|| '/' ||p_pais|| ' EL PAIS PARA ESTA APLICACION/VERSION NO EXISTE ';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);   
    WHEN eFka THEN
         RSP:= 'ERROR: ' || p_codigo || '/' ||p_version|| ' '||  'ESTA APLICACION/VERSION NO EXISTE O NO ESTA ACTIVA ';           
        SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);   
   
   WHEN OTHERS THEN
        ROLLBACK;
         
          mensaje_error := SUBSTR (SQLERRM, 1, 200);
          RSP:=    'ERROR: ' || mensaje_error;
          SP_ALTA_LOGS(sProcedure, p_entrada, 'RSP: '||RSP);
        
              
END SP_ALTA_DESCARGAS;